@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use JSON;
 use List::Util qw(first);
 
-our $VERSION = 0.5.2;
+use version; our $VERSION = version->declare('v0.6.1');
 
 sub new {
     my ($class, %params) = @_;
@@ -170,7 +170,7 @@ sub list_scans {
     my ($self, %params) = @_;
 
     my $result = $self->_get('/scans', %params);
-    return $result ? @{$result} : ();
+    return $result->{scans} ? @{$result->{scans}} : ();
 }
 
 sub launch_scan {
@@ -194,6 +194,16 @@ sub get_scan_details {
     return $result;
 }
 
+sub stop_scan {
+    my ($self, %params) = @_;
+
+    croak "missing scan_id parameter" unless $params{scan_id};
+
+    my $scan_id = delete $params{scan_id};
+    my $result  = $self->_post("/scans/$scan_id/stop", %params);
+    return $result;
+}
+
 sub set_scan_read_status {
     my ($self, %params) = @_;
 
@@ -355,7 +365,7 @@ sub list_scanners {
     my ($self) = @_;
 
     my $result = $self->_get("/scanners");
-    return $result->{scanner} ? @{$result->{scanner}} : ();
+    return $result->{scanners} ? @{$result->{scanners}} : ();
 }
 
 sub list_folders {
@@ -589,7 +599,10 @@ using REST interface.
         format  => 'pdf'
     );
 
-    while ($nessus->get_scan_export_status(scan_id => $scan_id, file_id => $file_id) ne 'ready') {
+    while ($nessus->get_scan_export_status(
+        scan_id => $scan->{id},
+        file_id => $file_id
+    ) ne 'ready') {
         sleep 1;
     }
 
@@ -811,6 +824,12 @@ my $fileuploaded = $result->{'fileuploaded'};
 
 See L<https://your.nessus.server:8834/api#/resources/file/upload> for details.
 
+=head2 $nessus->stop_scan(scan_id => $scan_id )
+
+Returns details for the given scan.
+
+See L<https://your.nessus.server:8834/nessus6-api.html#/resources/scans/stop> for details.
+
 =head1 LICENSE
 
 This program is free software: you can redistribute it and/or modify
